==> klayout-debug-0.30.4-3-x86_64.pkg.tar.zst: usr/src/debug/klayout/klayout-0.30.4/build-release/layui/layui/qrc_layLayoutStatistics.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.9.2
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // tree.stxml
  0x0,0x0,0x1,0x8a,
  0x3c,
  0x3f,0x78,0x6d,0x6c,0x20,0x76,0x65,0x72,0x73,0x69,0x6f,0x6e,0x3d,0x22,0x31,0x2e,
  0x30,0x22,0x3f,0x3e,0xa,0xa,0x3c,0x68,0x74,0x6d,0x6c,0x20,0x78,0x6d,0x6c,0x6e,
  0x73,0x3a,0x78,0x3d,0x22,0x77,0x77,0x77,0x2e,0x6b,0x6c,0x61,0x79,0x6f,0x75,0x74,
  0x2e,0x64,0x65,0x2f,0x6c,0x61,0x79,0x6f,0x75,0x74,0x2d,0x73,0x74,0x61,0x74,0x69,
  0x73,0x74,0x69,0x63,0x73,0x2d,0x74,0x65,0x6d,0x70,0x6c,0x61,0x74,0x65,0x22,0x3e,
  0xa,0x20,0x20,0x3c,0x62,0x6f,0x64,0x79,0x3e,0xa,0x20,0x20,0x20,0x20,0x3c,0x78,
  0x3a,0x71,0x75,0x65,0x72,0x79,0x20,0x65,0x78,0x70,0x72,0x3d,0x22,0x2e,0x2a,0x28,
  0x2e,0x2a,0x29,0x2a,0x22,0x20,0x6d,0x61,0x78,0x3d,0x22,0x31,0x30,0x30,0x30,0x22,
  0x3e,0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x3c,0x78,0x3a,0x65,0x61,0x63,0x68,0x3e,
  0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x24,0x28,0x22,0x26,0x23,0x31,0x36,
  0x30,0x3b,0x22,0x2a,0x28,0x68,0x69,0x65,0x72,0x5f,0x6c,0x65,0x76,0x65,0x6c,0x73,
  0x2a,0x34,0x29,0x29,0x3c,0x69,0x6d,0x67,0x20,0x73,0x72,0x63,0x3d,0x22,0x3a,0x2f,
  0x73,0x74,0x2f,0x73,0x74,0x5f,0x70,0x6c,0x75,0x73,0x5f,0x6e,0x6f,0x64,0x65,0x2e,
  0x70,0x6e,0x67,0x22,0x2f,0x3e,0x26,0x23,0x31,0x36,0x30,0x3b,0x24,0x28,0x63,0x65,
  0x6c,0x6c,0x5f,0x6e,0x61,0x6d,0x65,0x29,0x20,0x20,0x3c,0x62,0x72,0x2f,0x3e,0xa,
  0x20,0x20,0x20,0x20,0x20,0x20,0x3c,0x2f,0x78,0x3a,0x65,0x61,0x63,0x68,0x3e,0xa,
  0x20,0x20,0x20,0x20,0x20,0x20,0x3c,0x78,0x3a,0x6d,0x61,0x78,0x3e,0xa,0x20,0x20,
  0x20,0x20,0x20,0x20,0x20,0x20,0x3c,0x62,0x72,0x2f,0x3e,0x3c,0x69,0x3e,0x2e,0x2e,
  0x20,0x54,0x72,0x65,0x65,0x20,0x68,0x61,0x73,0x20,0x62,0x65,0x65,0x6e,0x20,0x73,
  0x68,0x6f,0x72,0x74,0x65,0x6e,0x65,0x64,0x20,0x28,0x6d,0x6f,0x72,0x65,0x20,0x74,
  0x68,0x61,0x6e,0x20,0x31,0x30,0x30,0x30,0x20,0x65,0x6e,0x74,0x72,0x69,0x65,0x73,
  0x29,0x20,0x2e,0x2e,0x3c,0x2f,0x69,0x3e,0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x3c,
  0x2f,0x78,0x3a,0x6d,0x61,0x78,0x3e,0xa,0x20,0x20,0x20,0x20,0x3c,0x2f,0x78,0x3a,
  0x71,0x75,0x65,0x72,0x79,0x3e,0xa,0x20,0x20,0x3c,0x2f,0x62,0x6f,0x64,0x79,0x3e,
  0xa,0x3c,0x2f,0x68,0x74,0x6d,0x6c,0x3e,0xa,
    // st_plus_node.png
  0x0,0x0,0x0,0xc8,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0x9,0x0,0x0,0x0,0x9,0x8,0x2,0x0,0x0,0x0,0x6f,0xf3,0x91,0x47,
  0x0,0x0,0x0,0x1,0x73,0x52,0x47,0x42,0x0,0xae,0xce,0x1c,0xe9,0x0,0x0,0x0,
  0x9,0x70,0x48,0x59,0x73,0x0,0x0,0xb,0x13,0x0,0x0,0xb,0x13,0x1,0x0,0x9a,
  0x9c,0x18,0x0,0x0,0x0,0x7,0x74,0x49,0x4d,0x45,0x7,0xdb,0x4,0x9,0x15,0x30,
  0xe,0x1e,0xb6,0xd5,0x69,0x0,0x0,0x0,0x19,0x74,0x45,0x58,0x74,0x43,0x6f,0x6d,
  0x6d,0x65,0x6e,0x74,0x0,0x43,0x72,0x65,0x61,0x74,0x65,0x64,0x20,0x77,0x69,0x74,
  0x68,0x20,0x47,0x49,0x4d,0x50,0x57,0x81,0xe,0x17,0x0,0x0,0x0,0x35,0x49,0x44,
  0x41,0x54,0x8,0xd7,0x63,0x60,0x60,0x60,0xf8,0xff,0xff,0x3f,0x56,0x92,0x11,0x42,
  0x61,0x5,0x4c,0x8c,0x8c,0x8c,0x70,0xe,0x1a,0x9b,0x9,0x97,0x3e,0xa8,0x38,0xa6,
  0x34,0x16,0xfb,0x18,0x19,0x51,0xb8,0x28,0xf6,0x21,0x3,0x46,0x34,0x85,0x38,0xad,
  0xc5,0x24,0x1,0xfb,0x8a,0x2f,0xec,0xf1,0xd0,0x14,0xb3,0x0,0x0,0x0,0x0,0x49,
  0x45,0x4e,0x44,0xae,0x42,0x60,0x82,
  
};

static const unsigned char qt_resource_name[] = {
  // st
  0x0,0x2,
  0x0,0x0,0x7,0xa4,
  0x0,0x73,
  0x0,0x74,
    // tree.stxml
  0x0,0xa,
  0x8,0x55,0xce,0x5c,
  0x0,0x74,
  0x0,0x72,0x0,0x65,0x0,0x65,0x0,0x2e,0x0,0x73,0x0,0x74,0x0,0x78,0x0,0x6d,0x0,0x6c,
    // st_plus_node.png
  0x0,0x10,
  0xb,0xc3,0xd2,0x67,
  0x0,0x73,
  0x0,0x74,0x0,0x5f,0x0,0x70,0x0,0x6c,0x0,0x75,0x0,0x73,0x0,0x5f,0x0,0x6e,0x0,0x6f,0x0,0x64,0x0,0x65,0x0,0x2e,0x0,0x70,0x0,0x6e,0x0,0x67,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x99,0xaf,0xd9,0x68,0xc8,
  // :/st
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x99,0xaf,0xd9,0x68,0xc8,
  // :/st/tree.stxml
  0x0,0x0,0x0,0xa,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x99,0xaf,0xd9,0x68,0xc8,
  // :/st/st_plus_node.png
  0x0,0x0,0x0,0x24,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x1,0x8e,
0x0,0x0,0x1,0x99,0xaf,0xd9,0x68,0xc8,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_layLayoutStatistics)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_layLayoutStatistics)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_layLayoutStatistics)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_layLayoutStatistics)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_layLayoutStatistics)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_layLayoutStatistics)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif

==> klayout-debug-0.30.5-1-x86_64.pkg.tar.zst: usr/src/debug/klayout/klayout-0.30.5/build-release/layui/layui/qrc_layLayoutStatistics.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.10.0
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // tree.stxml
  0x0,0x0,0x1,0x8a,
  0x3c,
  0x3f,0x78,0x6d,0x6c,0x20,0x76,0x65,0x72,0x73,0x69,0x6f,0x6e,0x3d,0x22,0x31,0x2e,
  0x30,0x22,0x3f,0x3e,0xa,0xa,0x3c,0x68,0x74,0x6d,0x6c,0x20,0x78,0x6d,0x6c,0x6e,
  0x73,0x3a,0x78,0x3d,0x22,0x77,0x77,0x77,0x2e,0x6b,0x6c,0x61,0x79,0x6f,0x75,0x74,
  0x2e,0x64,0x65,0x2f,0x6c,0x61,0x79,0x6f,0x75,0x74,0x2d,0x73,0x74,0x61,0x74,0x69,
  0x73,0x74,0x69,0x63,0x73,0x2d,0x74,0x65,0x6d,0x70,0x6c,0x61,0x74,0x65,0x22,0x3e,
  0xa,0x20,0x20,0x3c,0x62,0x6f,0x64,0x79,0x3e,0xa,0x20,0x20,0x20,0x20,0x3c,0x78,
  0x3a,0x71,0x75,0x65,0x72,0x79,0x20,0x65,0x78,0x70,0x72,0x3d,0x22,0x2e,0x2a,0x28,
  0x2e,0x2a,0x29,0x2a,0x22,0x20,0x6d,0x61,0x78,0x3d,0x22,0x31,0x30,0x30,0x30,0x22,
  0x3e,0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x3c,0x78,0x3a,0x65,0x61,0x63,0x68,0x3e,
  0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x24,0x28,0x22,0x26,0x23,0x31,0x36,
  0x30,0x3b,0x22,0x2a,0x28,0x68,0x69,0x65,0x72,0x5f,0x6c,0x65,0x76,0x65,0x6c,0x73,
  0x2a,0x34,0x29,0x29,0x3c,0x69,0x6d,0x67,0x20,0x73,0x72,0x63,0x3d,0x22,0x3a,0x2f,
  0x73,0x74,0x2f,0x73,0x74,0x5f,0x70,0x6c,0x75,0x73,0x5f,0x6e,0x6f,0x64,0x65,0x2e,
  0x70,0x6e,0x67,0x22,0x2f,0x3e,0x26,0x23,0x31,0x36,0x30,0x3b,0x24,0x28,0x63,0x65,
  0x6c,0x6c,0x5f,0x6e,0x61,0x6d,0x65,0x29,0x20,0x20,0x3c,0x62,0x72,0x2f,0x3e,0xa,
  0x20,0x20,0x20,0x20,0x20,0x20,0x3c,0x2f,0x78,0x3a,0x65,0x61,0x63,0x68,0x3e,0xa,
  0x20,0x20,0x20,0x20,0x20,0x20,0x3c,0x78,0x3a,0x6d,0x61,0x78,0x3e,0xa,0x20,0x20,
  0x20,0x20,0x20,0x20,0x20,0x20,0x3c,0x62,0x72,0x2f,0x3e,0x3c,0x69,0x3e,0x2e,0x2e,
  0x20,0x54,0x72,0x65,0x65,0x20,0x68,0x61,0x73,0x20,0x62,0x65,0x65,0x6e,0x20,0x73,
  0x68,0x6f,0x72,0x74,0x65,0x6e,0x65,0x64,0x20,0x28,0x6d,0x6f,0x72,0x65,0x20,0x74,
  0x68,0x61,0x6e,0x20,0x31,0x30,0x30,0x30,0x20,0x65,0x6e,0x74,0x72,0x69,0x65,0x73,
  0x29,0x20,0x2e,0x2e,0x3c,0x2f,0x69,0x3e,0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x3c,
  0x2f,0x78,0x3a,0x6d,0x61,0x78,0x3e,0xa,0x20,0x20,0x20,0x20,0x3c,0x2f,0x78,0x3a,
  0x71,0x75,0x65,0x72,0x79,0x3e,0xa,0x20,0x20,0x3c,0x2f,0x62,0x6f,0x64,0x79,0x3e,
  0xa,0x3c,0x2f,0x68,0x74,0x6d,0x6c,0x3e,0xa,
    // st_plus_node.png
  0x0,0x0,0x0,0xc8,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0x9,0x0,0x0,0x0,0x9,0x8,0x2,0x0,0x0,0x0,0x6f,0xf3,0x91,0x47,
  0x0,0x0,0x0,0x1,0x73,0x52,0x47,0x42,0x0,0xae,0xce,0x1c,0xe9,0x0,0x0,0x0,
  0x9,0x70,0x48,0x59,0x73,0x0,0x0,0xb,0x13,0x0,0x0,0xb,0x13,0x1,0x0,0x9a,
  0x9c,0x18,0x0,0x0,0x0,0x7,0x74,0x49,0x4d,0x45,0x7,0xdb,0x4,0x9,0x15,0x30,
  0xe,0x1e,0xb6,0xd5,0x69,0x0,0x0,0x0,0x19,0x74,0x45,0x58,0x74,0x43,0x6f,0x6d,
  0x6d,0x65,0x6e,0x74,0x0,0x43,0x72,0x65,0x61,0x74,0x65,0x64,0x20,0x77,0x69,0x74,
  0x68,0x20,0x47,0x49,0x4d,0x50,0x57,0x81,0xe,0x17,0x0,0x0,0x0,0x35,0x49,0x44,
  0x41,0x54,0x8,0xd7,0x63,0x60,0x60,0x60,0xf8,0xff,0xff,0x3f,0x56,0x92,0x11,0x42,
  0x61,0x5,0x4c,0x8c,0x8c,0x8c,0x70,0xe,0x1a,0x9b,0x9,0x97,0x3e,0xa8,0x38,0xa6,
  0x34,0x16,0xfb,0x18,0x19,0x51,0xb8,0x28,0xf6,0x21,0x3,0x46,0x34,0x85,0x38,0xad,
  0xc5,0x24,0x1,0xfb,0x8a,0x2f,0xec,0xf1,0xd0,0x14,0xb3,0x0,0x0,0x0,0x0,0x49,
  0x45,0x4e,0x44,0xae,0x42,0x60,0x82,
  
};

static const unsigned char qt_resource_name[] = {
  // st
  0x0,0x2,
  0x0,0x0,0x7,0xa4,
  0x0,0x73,
  0x0,0x74,
    // tree.stxml
  0x0,0xa,
  0x8,0x55,0xce,0x5c,
  0x0,0x74,
  0x0,0x72,0x0,0x65,0x0,0x65,0x0,0x2e,0x0,0x73,0x0,0x74,0x0,0x78,0x0,0x6d,0x0,0x6c,
    // st_plus_node.png
  0x0,0x10,
  0xb,0xc3,0xd2,0x67,
  0x0,0x73,
  0x0,0x74,0x0,0x5f,0x0,0x70,0x0,0x6c,0x0,0x75,0x0,0x73,0x0,0x5f,0x0,0x6e,0x0,0x6f,0x0,0x64,0x0,0x65,0x0,0x2e,0x0,0x70,0x0,0x6e,0x0,0x67,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x9a,0x7c,0x72,0x2d,0xe8,
  // :/st
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x9a,0x7c,0x72,0x2d,0xe8,
  // :/st/tree.stxml
  0x0,0x0,0x0,0xa,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x9a,0x7c,0x72,0x2d,0xe8,
  // :/st/st_plus_node.png
  0x0,0x0,0x0,0x24,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x1,0x8e,
0x0,0x0,0x1,0x9a,0x7c,0x72,0x2d,0xe8,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_layLayoutStatistics)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_layLayoutStatistics)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_layLayoutStatistics)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_layLayoutStatistics)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_layLayoutStatistics)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_layLayoutStatistics)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
